# cosipy
The COSI high-level data analysis tools

## Installation from source

Meant for developers. Currently the only option.

1. Clone the repository into your local machine

```
git clone git@github.com:cositools/cosipy.git
```

2. Move to the cosipy folder

```
cd cosipy
```

3. Create a new conda environment. Optional but highly encouranged.

4. Install it:

```
pip install -e .
```
